/*
 * Copyright 2005 Sun Microsystems, Inc.
 * Property of Sun Microsystems, Inc.
 */

package com.sun.im.provider.sample;

import com.sun.im.provider.*;
import com.sun.im.service.*;

/**
 *
 * @author Rahul
 */
public class SamplePolicyProvider extends PolicyProvider {
    
    /** Creates a new instance of SamplePolicyProvider */
    public SamplePolicyProvider() {
    }
    
    /**
    * Checks if the user has permission to send alerts. 
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkSendAlertsPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Checks if the user can use the chat feature 
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkChatPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can access conference rooms
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkAccessConferencePermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can manage conference rooms
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkManageConferencePermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can moderate conference rooms 
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkModerateConferencePermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can receive alerts.
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkReceiveAlertsPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can receive alerts
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkReceivePollsPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can access news channels 
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkAccessNewsPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can manage news channel
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkManageNewsPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * @param u principal doing the request
    * @return true if the user can send alerts
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkManageRosterPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can change his or her own settings 
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkChangeSettingsPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can send poll messages
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkPollPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can send chat invitations to other users
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkInvitePermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * @param u principal doing the request
    * @return true if the user can access others presence information
    */
    //public  boolean canWatch(CollaborationPrincipal u);

   /**
    * Check if the user can manage his or her presence provacy rules
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkManagePresenceACLPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can use the file transfer funcionality
    * (send or receive) 
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkTransferFilesPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user can advertise his or her presence
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkPublishPresencePermission(CollaborationPrincipal u) {
        return ALLOWED;
    }
    
   /**
    * Check if the user can access to other users presence information
    * @param u principal doing the request
    * @return Result based on the policy. The default value is ALLOWED
    */
    public Result checkWatchPermission(CollaborationPrincipal u) {
        return ALLOWED;
    }

   /**
    * Check if the user is an I adminstrator, and so has no access 
    * restrictions to any data managed by the IM and presence services.
    * @param u principal doing the request
    * @return Result based on the policy. The default value is NOT_ALLOWED
    */
    public Result checkAdminPermission(CollaborationPrincipal u) {
        return NOT_ALLOWED;
    }
    

   /**
    * retrieve the presence access control list for a user
    * @param u principal whose presence is protected by these rules 
    * @param by principal doing the request
    * @return u's access control list

    public  AccessControlList getPresenceACL(CollaborationPrincipal u, CollaborationPrincipal by) throws Exception;
    */

   /**
    * sets the presence access controls for a user
    * @param u principal whose presence is protected by these rules 
    * @param by principal doing the request
    * @return true if the request succeeded

    public  boolean setPresenceACL(CollaborationPrincipal u, CollaborationPrincipal by, AccessControlList l) throws Exception;
    */

   /**
    * @param watcher principal doing the request
    * @param target principal doing whose presence is being requested 
    * @return true if access to the target's presence s granted 
    */
    //public boolean canWatch(CollaborationPrincipal watcher, CollaborationPrincipal target);

    /**
     * Returns the access level of a principal into a conference.
     *
     * Note: the access level returned may not be higher than that 
     * derived from affiliations for the destination.
     *
     * @param u principal requesting access to the conference
     * @param destination serialized conference address
     * @param secret a password or token included in the join request,
     *        if any.
     * @param wouldbeAccess The AccessLevelResult for the user based on the Conference
     * affiliations.
     * @return a Result with an valid AccessLevelResult as defined in this class.
     */
    public Result getConferenceAccess(CollaborationPrincipal u, 
				      String destination, 
				      String secret,
                                      AccessLevelResult wouldbeAccess)
    {
        if (wouldbeAccess.getAccessLevel() >= AccessControlItem.MANAGE) {
            System.out.println("User[" + u.getUID() + "] Requesting Manage Access, password is " + secret);
            //verify if the secret is correct
            return wouldbeAccess; //password is correct
            
            //if password is incorrect
            //return NOT_ALLOWED;
        } else if (wouldbeAccess.getAccessLevel() >= AccessControlItem.WRITE) {
            System.out.println("User[" + u.getUID() + "] Requesting write Access, password is " + secret);
            //verify if the secret is correct
            //return wouldbeAccess; //password is correct
            
            //if password is incorrect
            //return NOT_ALLOWED;
            return getAccessLevelResult(AccessControlItem.READ); //lower the access
        } else if (wouldbeAccess.getAccessLevel() >= AccessControlItem.READ) {
            System.out.println("User[" + u.getUID() + "] Requesting read Access, password is " + secret);
            //verify if the secret is correct
            return wouldbeAccess; //password is correct
            
            //if password is incorrect
            //return NOT_ALLOWED;
        }

        //return a custom error message
        Result error = NOT_ALLOWED.getCopy("custom error message", null);
	return error;
    }

    
}
